@@ -112,6 +112,10 @@ def date_range_params(period_config, comparison, period, reference_date):
         start_date = (today + relativedelta(years=-1)).strftime("%Y-%m-01")
         end_date = (today + relativedelta(years=-1) + relativedelta(months=1)).strftime("%Y-%m-01")
 
+    elif period_config == "last_month":
+        start_date = (today + relativedelta(months=-1)).strftime("%Y-%m-01")
+        end_date = today.strftime("%Y-%m-01")
+
     elif period_config == "lymtd":
         start_date = (today + relativedelta(years=-1)).strftime("%Y-%m-01")
         end_date = (today + relativedelta(years=-1)).strftime("%Y-%m-%d")
